@@ -5,38 +5,32 @@
 #include <sys/types.h> /* for pid_t */
 #endif
 
-#ifdef USE_REGEX
+#ifdef HAVE_REGEX_H
 #include <regex.h>	/* for regex_t */
 #endif
-
-#ifdef USE_REGEX
 typedef struct {
+#ifdef HAVE_REGEX_H
 	regex_t *ptrs;
-	int nr;
-} my_regex, *pmy_regex;
 #endif
+	char *header;
+	char *string;
+	void *next;
+} my_regex, *pmy_regex;
 
 /* this is a structure so can add other kill options later */
 typedef struct {
 	int hilines;	/* nr of lines max article length */
 	int lowlines;	/* nr of lines min article length */
 	int maxgrps;	/* max nr of grps (to prevent spams) */
+	unsigned long bodybig;	/* max size of article body  */
+	unsigned long bodysmall; /* minimum size of article body */
 	char quote;	/* character to use as quote (for case compare) */
-	char pathhost_sep;
-	char subject_sep;
-	char from_sep;
-	char nntp_sep;
-#ifdef USE_REGEX
-	my_regex path;
-	my_regex from;
-	my_regex subj;
-	my_regex nntphost;
-#else
-	char *path;	/* which hosts in path to kill */
-	char *from;	/* look for name in from to kill */
-	char *subj;	/* look for words in subj to kill */
-	char *nntphost;	/* look for words in nntp_posting_host */
+#ifdef HAVE_REGEX_H	
+	int use_extended;	/* do we use extended regex */
 #endif
+	pmy_regex header;       /* scan the entire header */
+	pmy_regex body;		/* scan the body */
+	pmy_regex list;	/* linked list of headers and what to match */
 } OneKill, *POneKill;
 
 typedef struct {
@@ -52,23 +46,31 @@ typedef struct {
 } Child;
  
 typedef struct killstruct {
+	FILE *logfp;
 	int logyn;
+	int grp_override;
+	int tie_delete;
 	int totgrps;
+	int ignore_postfix;
 	PGroup grps;	/* dynamicly allocated array */
-	int ( *killfunc)(struct killstruct *, char *); /*function to call */
+	int ( *killfunc)(PMaster, struct killstruct *, char *, int); /*function to call to check header */
+	char *pbody;
+	unsigned long bodylen;
+	int use_extended_regex;
 	Child child;		/* these two are last since can't initialize */
 	OneKill master;
 } KillStruct, *PKillStruct;
 
 /* function prototypes for killfile.c */
-int get_one_article_kill(PMaster, int, PKillStruct);
-PKillStruct parse_killfile(int);
+int get_one_article_kill(PMaster, int);
+PKillStruct parse_killfile(int, int, int);
 void free_killfile(PKillStruct);
-int chk_msg_kill(PKillStruct, char *);
+int chk_msg_kill(PMaster, PKillStruct, char *, int);
 
 /* function prototypes for killprg.c */
-int killprg_forkit(PKillStruct, char *);
-int chk_msg_kill_fork(PKillStruct, char *);
+int killprg_forkit(PKillStruct, char *, int);
+int chk_msg_kill_fork(PMaster, PKillStruct, char *, int);
 void killprg_closeit(PKillStruct);
 
+enum { KILL_LOG_NONE, KILL_LOG_SHORT, KILL_LOG_LONG };  /* what level of logging do we use */
 #endif /* _SUCK_KILLFILE_H */
